@@ -16,7 +16,6 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <dlfcn.h>
 #include <girepository.h>
 #include <math.h>
 #include <string.h>
@@ -1114,10 +1113,12 @@ lookup_for_object:
       n_ifaces = g_object_info_get_n_interfaces ((GIObjectInfo *)base_info);
       for (i = 0; function == NULL && i < n_ifaces; i++)
         {
-          GIInterfaceInfo *iface_info;
+          GIInterfaceInfo *iface_info = NULL;
 
           iface_info = g_object_info_get_interface ((GIObjectInfo *)base_info, i);
           function = g_interface_info_find_method (iface_info, node->name);
+
+          g_clear_pointer (&iface_info, g_base_info_unref);
         }
 
       if (function != NULL)
