@@ -84,6 +84,21 @@ TmplExpr *tmpl_expr_new_symbol_ref    (const gchar      *symbol);
 TMPL_AVAILABLE_IN_ALL
 TmplExpr *tmpl_expr_new_symbol_assign (const gchar      *symbol,
                                        TmplExpr         *right);
+TMPL_AVAILABLE_IN_3_36
+TmplExpr *tmpl_expr_new_stmt_list     (GPtrArray        *stmts);
+TMPL_AVAILABLE_IN_3_36
+TmplExpr *tmpl_expr_new_func          (char             *name,
+                                       char            **symlist,
+                                       TmplExpr         *list);
+TMPL_AVAILABLE_IN_3_36
+TmplExpr *tmpl_expr_new_anon_call     (TmplExpr         *func,
+                                       TmplExpr         *params);
+TMPL_AVAILABLE_IN_3_36
+TmplExpr *tmpl_expr_new_nop           (void);
+TMPL_AVAILABLE_IN_3_36
+TmplExpr *tmpl_expr_new_null          (void);
+
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (TmplExpr, tmpl_expr_unref)
 
 G_END_DECLS
 
